'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _effects = require('redux-saga/effects');

var _bootstrapStyled = require('bootstrap-styled');

var _actions = require('@bootstrap-styled/redux/lib/actions');

var _constants = require('../constants');

var _actions2 = require('../actions');

var _saga = require('../saga');

var _saga2 = _interopRequireDefault(_saga);

var _themeProvider = require('../../styleguide/components/tests/themeProvider');

var _themeProvider2 = _interopRequireDefault(_themeProvider);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable redux-saga/yield-effects */
describe('bootstrapSaga Saga', function () {
  var bootstrapSaga = void 0;

  it('should start task to watch for CHANGE_THEME_REQUEST action using keys as themes', function () {
    bootstrapSaga = (0, _saga2.default)(_themeProvider2.default, Object.keys(_themeProvider.themes))();

    var takeLatestDescriptor = bootstrapSaga.next().value;
    expect(JSON.stringify(takeLatestDescriptor)).toEqual(JSON.stringify((0, _effects.all)([(0, _effects.takeLatest)(_constants.CHANGE_THEME_REQUEST, (0, _saga.makeLoadTheme)(_themeProvider2.default))].concat(Object.keys(_themeProvider.themes).map(function (key) {
      return (0, _effects.put)((0, _actions2.storeAsyncTheme)({ _name: key, _async: true, _loaded: false }));
    })))));
  });

  it('should start task to watch for CHANGE_THEME_REQUEST action using themes object', function () {
    bootstrapSaga = (0, _saga2.default)(_themeProvider2.default, _themeProvider.themes)();

    var takeLatestDescriptor = bootstrapSaga.next().value;
    expect(JSON.stringify(takeLatestDescriptor)).toEqual(JSON.stringify((0, _effects.all)([(0, _effects.takeLatest)(_constants.CHANGE_THEME_REQUEST, (0, _saga.makeLoadTheme)(_themeProvider2.default))].concat(Object.keys(_themeProvider.themes).map(function (key) {
      return (0, _effects.put)((0, _actions2.storeAsyncTheme)({ _name: key, _async: true, _loaded: false }));
    })))));
  });
});

describe('makeLoadTheme Saga', function () {
  var loadThemeGenerator = void 0;
  var name = void 0;

  // We have to test twice, once for a successful load and once for an unsuccessful one
  // so we do all the stuff that HAPPENS beforehand automatically in the beforeEach
  beforeEach(function () {
    name = _bootstrapStyled.theme._name; // eslint-disable-line no-underscore-dangle
    loadThemeGenerator = (0, _saga.makeLoadTheme)(_themeProvider2.default)({ name: name });
    var descriptor = loadThemeGenerator.next().value;
    expect(descriptor).toEqual((0, _effects.call)(_themeProvider2.default, name));
  });

  it('should dispatch the changeTheme action if it requests the data successfully', function () {
    var putDescriptor = loadThemeGenerator.next(_bootstrapStyled.theme).value;
    expect(putDescriptor).toEqual((0, _effects.put)((0, _actions.changeTheme)(_extends({}, _bootstrapStyled.theme, { _async: true, _loaded: true }))));
  });

  it('should call the changeThemeFailure action if the response errors', function () {
    var response = new Error('Some error');
    var putDescriptor = loadThemeGenerator.throw(response).value;
    expect(putDescriptor).toEqual((0, _effects.put)((0, _actions2.changeThemeFailure)(name, response)));
  });
});